//   Copyright 2012 Georg-August-Universität Göttingen, Germany
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

package de.ugoe.cs.autoquest.eventcore.gui;

import de.ugoe.cs.autoquest.eventcore.IEventType;

/**
 * <p>
 * An interaction is a special event type which represents the interaction of a user with an element
 * of a GUI. An example is a mouse click on a button.
 * </p>
 * 
 * @version 1.0
 * @author Patrick Harms
 */
public interface IInteraction extends IEventType {
    /**
     * <p>
     * Determines whether an event type starts a logical sequence, i.e., a task.
     * </p>
     * 
     * @return true if a logical sequence is started; false otherwise
     */
    public boolean startsLogicalSequence();

    /**
     * <p>
     * Determines whether an event type finishes a logical sequence, i.e., a task.
     * </p>
     * 
     * @return true if a logical sequence is finished; false otherwise
     */
    public boolean finishesLogicalSequence();

}
